==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/ponder/foundation/level/PonderChunkSection.java <==
package com.zurrtum.create.client.ponder.foundation.level;

import net.minecraft.class_1923;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2826;
import net.minecraft.class_3610;
import net.minecraft.class_7924;

public class PonderChunkSection extends class_2826 {
    public final PonderChunk owner;
    protected final class_2338.class_2339 scratchPos;

    public final int xStart;
    public final int yStart;
    public final int zStart;
    public boolean empty;

    public PonderChunkSection(PonderChunk owner, class_2338.class_2339 scratchPos, class_1923 pos, int yBase, boolean hasBlock) {
        super(owner.world.method_30349().method_30530(class_7924.field_41236));
        this.owner = owner;
        this.scratchPos = scratchPos;
        this.xStart = pos.method_8326();
        this.yStart = yBase;
        this.zStart = pos.method_8328();
        this.empty = !hasBlock;
    }

    @Override
    public class_2680 method_12254(int x, int y, int z) {
        // ChunkSection#getBlockState expects local chunk coordinates, so we add to get
        // back into world coords.
        return owner.world.method_8320(scratchPos.method_10103(x + xStart, y + yStart, z + zStart));
    }

    @Override
    public class_3610 method_12255(int x, int y, int z) {
        return method_12254(x, y, z).method_26227();
    }

    @Override
    public class_2680 method_12256(int x, int y, int z, class_2680 state, boolean useLocks) {
        throw new UnsupportedOperationException("Chunk sections cannot be mutated in a fake world.");
    }

    @Override
    public boolean method_38292() {
        return empty;
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/client/ponder/foundation/level/PonderChunkSection.java <==
package com.zurrtum.create.client.ponder.foundation.level;

import net.minecraft.class_1923;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_2826;
import net.minecraft.class_3610;

public class PonderChunkSection extends class_2826 {
    public final PonderChunk owner;
    protected final class_2338.class_2339 scratchPos;

    public final int xStart;
    public final int yStart;
    public final int zStart;
    public boolean empty;

    public PonderChunkSection(PonderChunk owner, class_2338.class_2339 scratchPos, class_1923 pos, int yBase, boolean hasBlock) {
        super(owner.world.method_74142());
        this.owner = owner;
        this.scratchPos = scratchPos;
        this.xStart = pos.method_8326();
        this.yStart = yBase;
        this.zStart = pos.method_8328();
        this.empty = !hasBlock;
    }

    @Override
    public class_2680 method_12254(int x, int y, int z) {
        // ChunkSection#getBlockState expects local chunk coordinates, so we add to get
        // back into world coords.
        return owner.world.method_8320(scratchPos.method_10103(x + xStart, y + yStart, z + zStart));
    }

    @Override
    public class_3610 method_12255(int x, int y, int z) {
        return method_12254(x, y, z).method_26227();
    }

    @Override
    public class_2680 method_12256(int x, int y, int z, class_2680 state, boolean useLocks) {
        throw new UnsupportedOperationException("Chunk sections cannot be mutated in a fake world.");
    }

    @Override
    public boolean method_38292() {
        return empty;
    }
}
